@@ -1055,7 +1055,9 @@ void DockView::setMaskArea(QRect area)
         //! this is used when compositing is disabled and provides
         //! the correct way for the mask to be painted in order for
         //! rounded corners to be shown correctly
-        if (!m_background) {
+        //! the enabledBorders check was added because there was cases
+        //! that the mask region wasnt calculated correctly after location changes
+        if (!m_background || m_background->enabledBorders() != enabledBorders()) {
             m_background = new Plasma::FrameSvg(this);
         }
 
@@ -1420,7 +1422,11 @@ void DockView::toggleAppletExpanded(const int id)
             PlasmaQuick::AppletQuickItem *ai = applet->property("_plasma_graphicObject").value<PlasmaQuick::AppletQuickItem *>();
 
             if (ai) {
-                ai->setExpanded(!ai->isExpanded());
+                if (!ai->isActivationTogglesExpanded()) {
+                    ai->setActivationTogglesExpanded(true);
+                }
+
+                emit applet->activated();
             }
         }
     }
@@ -1547,7 +1553,8 @@ void DockView::mousePressEvent(QMouseEvent *event)
                 KPluginMetaData meta = applet->kPackage().metadata();
 
                 //Try to find applets inside a systray
-                if (meta.pluginId() == "org.kde.plasma.systemtray") {
+                if (meta.pluginId() == "org.kde.plasma.systemtray" ||
+                    meta.pluginId() == "org.nomad.systemtray") {
                     auto systrayId = applet->config().readEntry("SystrayContainmentId");
                     applet = 0;
                     inSystray = true;
